@@ -123,7 +123,7 @@ static void place_team (int part, int team)
   fighters=CURRENT_ARMY_SIZE/PLAYING_TEAMS;
   ACTIVE_FIGHTERS[team]=0;
   /*
-    health=fsqrt(fsqrt(1<<CONFIG_FIGHTER_NEW_HEALTH))/4;
+    health=fsqrt(fsqrt(1<<LW_CONFIG_CURRENT_rULES.FIGHTER_NEW_HEALTH))/4;
     if (health>=MAX_FIGHTER_HEALTH)*/
   health=MAX_FIGHTER_HEALTH-1;
 
@@ -257,7 +257,7 @@ int create_army (void)
   int ret=-1,i;
 
   CURRENT_ARMY_SIZE= (get_battle_room()
-		      *(CONFIG_FIGHTER_NUMBER+1))/64;
+		      *(LW_CONFIG_CURRENT_RULES.fighter_number+1))/64;
 
   CURRENT_ARMY_SIZE/=PLAYING_TEAMS;
   if (CURRENT_ARMY_SIZE<1)
