@@ -56,6 +56,7 @@
 /*==================================================================*/
 
 #include "base.h"
+#include "netconf.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -108,11 +109,14 @@ extern int CONFIG_FRAMES_PER_SEC_LIMIT;
 extern int CONFIG_ROUNDS_PER_SEC_LIMIT;
 extern char CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE+1];
 extern int CONFIG_SERVER_PORT;
+extern int CONFIG_ASM_ALGORITHM;
 
 #define CONFIG_CONTROL_TYPE_OFF    0
 #define CONFIG_CONTROL_TYPE_HUMAN  1
 #define CONFIG_CONTROL_TYPE_CPU    2
 
+extern LW_NETCONF LW_CONFIG_CURRENT_RULES;
+
 /*==================================================================*/
 /* constantes globales                                              */
 /*==================================================================*/
@@ -128,5 +132,6 @@ void load_default_options (void);
 int load_config_options (void);
 int save_config_options (void);
 void check_config_range (void);
+void lw_config_set_current_rules_to_default (void);
 
 #endif
