@@ -178,8 +178,14 @@ int lw_connect_menu (int sock)
 
       if (hide_start_button)
 	{
+	  /*
+	   * We disactivate these buttons. If we did not do it
+	   * it would lead to network errors if someone would
+	   * press them twice.
+	   */
 	  d[6].proc=my_textbox_proc;
 	  d[6].dp=lw_lang_string(LW_LANG_STRING_CONNECT_WAITING);
+	  d[MENU_QUICK_PLAY].flags=D_HIDDEN;
 	}
 
       d[11].proc=0;
@@ -189,7 +195,7 @@ int lw_connect_menu (int sock)
 	  display_back_image();
 	  first_display=0;
 	}
-      dp=init_dialog (d,choix);
+      dp=my_init_dialog (d,choix);
       while (my_update_dialog (dp) && !data->finished)
 	{
 	  show_mouse(screen);
@@ -396,75 +402,90 @@ static void connect_on_server_keepalive(void *arg)
 
   data=(LW_CONNECT_DATA *) arg;
 
-  if (result==1)
-    {
-      if (!lw_protocol_waiting(data->sock,&(data->waited_teams)))
-	{
-	  result=0;
-	}
-    }
-
-  for (i=0;i<NB_TEAMS;++i)
+  if (!data->finished)
     {
       if (result==1)
 	{
-	  if (!lw_protocol_ask_teamstartinfo(data->sock,i,
-					     &(data->team_start_info[i])))
+	  if (!lw_protocol_waiting(data->sock,&(data->waited_teams)))
 	    {
 	      result=0;
 	    }
 	}
-    }
 
-  if (result==1 && data->chat_send)
-    {
-      lw_netmess_cleanup_arg(data->chat_buffer);
-
-      if (!lw_protocol_chat_talk(data->sock,data->chat_buffer))
+      if (result==1) 
 	{
-	  result=0;
-	}
-
-      data->chat_send=0;
-    }
-
-  if (result==1)
-    {
-      if (!lw_protocol_chat_listen(data->sock,&(data->chat_history)))
-	{
-	  result=0;
-	}
-    }
-
-  if (result==1 && data->force_start)
-    {
-      if (!lw_protocol_force_start(data->sock))
-	{
-	  result=0;
-	}
-      /*
-       * It's useless to keep on sending the START message, once is
-       * just enough, let's save bandwidth!
-       */
-      data->force_start=0;
-    }
-
-  if (result==1)
-    { 
-      if (data->waited_teams==0)
-	{
-	  if (!lw_protocol_i_am_ready(data->sock))
+	  if (data->waited_teams>0)
 	    {
-	      result=0;
+	      /*
+	       * We are still waiting for teams
+	       */
+	      for (i=0;i<NB_TEAMS;++i)
+		{
+		  if (result==1)
+		    {
+		      if (!lw_protocol_ask_teamstartinfo(data->sock,i,
+							 &(data->team_start_info[i])))
+			{
+			  result=0;
+			}
+		    }
+		}
+	  
+	      if (result==1 && data->chat_send)
+		{
+		  lw_netmess_cleanup_arg(data->chat_buffer);
+	      
+		  if (!lw_protocol_chat_talk(data->sock,data->chat_buffer))
+		    {
+		      result=0;
+		    }
+	      
+		  data->chat_send=0;
+		}
+	  
+	      if (result==1)
+		{
+		  if (!lw_protocol_chat_listen(data->sock,&(data->chat_history)))
+		    {
+		      result=0;
+		    }
+		}
+	  
+	      if (result==1 && data->force_start)
+		{
+		  if (!lw_protocol_force_start(data->sock))
+		    {
+		      result=0;
+		    }
+		  /*
+		   * It's useless to keep on sending the START message, once is
+		   * just enough, let's save bandwidth!
+		   */
+		  data->force_start=0;
+		}
+
+	      if (result==1)
+		{ 
+		  if (!lw_protocol_next(data->sock))
+		    {
+		      result=0;
+		    }      
+		}
 	    }
-	  data->finished=1;
-	}
-      else
-	{
-	  if (!lw_protocol_next(data->sock))
+	  else
 	    {
-	      result=0;
-	    }      
+	      /*
+	       * No more teams waited, we say we're ready
+	       */
+	      if (result==1)
+		{ 
+		  if (!lw_protocol_i_am_ready(data->sock))
+		    {
+		      result=0;
+		    }
+		  data->finished=1;
+		}
+	    }
 	}
     }
 
