@@ -59,6 +59,7 @@
 #include "back.h"
 #include "lang.h"
 #include "exit.h"
+#include "keyboard.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -238,13 +239,25 @@ void main_info (DIALOG *d, char *str)
   d->flags=0;
 }
 
+/*------------------------------------------------------------------*/
+DIALOG_PLAYER *my_init_dialog (DIALOG *d, int f)
+{
+  DIALOG_PLAYER *dp;
+
+  lw_keyboard_reset_hack();
+
+  dp=init_dialog(d, f);
+
+  return dp;
+}
+
 /*------------------------------------------------------------------*/
 int my_do_dialog_no_clear (DIALOG *d, int f)
 {
   int result;
   void *player;
   
-  player = init_dialog(d, f);
+  player = my_init_dialog(d, f);
   
   while (my_update_dialog(player))
     {
@@ -279,6 +292,8 @@ int my_update_dialog (DIALOG_PLAYER *player)
   result=update_dialog(player);
   my_exit_poll();
 
+  yield_timeslice();
+
   return result;
 }
 
@@ -293,7 +308,7 @@ void display_center_message (char *str)
   display_back_image ();
   main_message (d,str);
   d[1].proc=0;
-  dp=init_dialog (d,0);
+  dp=my_init_dialog (d,0);
   my_update_dialog (dp);
   shutdown_dialog (dp);
 
@@ -316,4 +331,3 @@ int slider_int (void *dp3, int d2)
   return 0;
 }
 
-
