@@ -68,6 +68,7 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+int SAMPLE_WATER_NUMBER=0;
 int RAW_TEXTURE_NUMBER=0;
 int RAW_MAP_NUMBER=0;
 int MIDI_MUSIC_NUMBER=0;
@@ -84,7 +85,7 @@ SAMPLE *SAMPLE_SFX_GO=NULL;
 SAMPLE *SAMPLE_SFX_CLICK=NULL;
 SAMPLE *SAMPLE_SFX_LOOSE=NULL;
 
-SAMPLE *SAMPLE_WATER[SAMPLE_WATER_NUMBER];
+SAMPLE *SAMPLE_WATER[SAMPLE_WATER_MAX_NUMBER];
 void   *RAW_MAP[RAW_MAP_MAX_NUMBER];
 void   *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
 void   *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
@@ -139,10 +140,11 @@ static void read_water_dat (DATAFILE *df)
 {
   int i;
 
-  for (i=0; i<SAMPLE_WATER_NUMBER; ++i)
+  for (i=0; i<SAMPLE_WATER_DAT_NUMBER && df[i].type!=DAT_END; ++i)
     {
       SAMPLE_WATER[i]=df[i].dat;
       lock_sound (SAMPLE_WATER[i]);
+      SAMPLE_WATER_NUMBER++;
     }
 }
 
