@@ -286,10 +286,10 @@ void move_fighters (void)
   sens=0;
 
   for (i=0;i<NB_TEAMS;++i)
-    if (CURRENT_CURSOR[i].cpu_or_human
+    if (CURRENT_CURSOR[i].control_type == CONFIG_CONTROL_TYPE_CPU
         && CURRENT_CURSOR[i].active)
       cpu_influence[CURRENT_CURSOR[i].team]=
-        CONFIG_CPU_ADVANTAGE;
+        LW_CONFIG_CURRENT_RULES.cpu_advantage;
 
   for (i=0;i<PLAYING_TEAMS;++i)
     {
@@ -299,16 +299,16 @@ void move_fighters (void)
       if (coef>256)
 	coef=256;
 
-      coef*=(CONFIG_NUMBER_INFLUENCE-8)*(CONFIG_NUMBER_INFLUENCE-8);
+      coef*=(LW_CONFIG_CURRENT_RULES.number_influence-8)*(LW_CONFIG_CURRENT_RULES.number_influence-8);
       coef/=64;
-      if (CONFIG_NUMBER_INFLUENCE<8)
+      if (LW_CONFIG_CURRENT_RULES.number_influence<8)
 	coef=-coef;
       if (coef<0)
 	coef/=2;
       coef+=256;
 
       attack[i]= (coef*
-		  fsqrt(fsqrt (1<<(CONFIG_FIGHTER_ATTACK
+		  fsqrt(fsqrt (1<<(LW_CONFIG_CURRENT_RULES.fighter_attack
 				   +cpu_influence[i]))))
 	/(256*8);
       if (attack[i]>=MAX_FIGHTER_HEALTH)
@@ -317,7 +317,7 @@ void move_fighters (void)
 	attack[i]=1;
 
       defense[i]= (coef*
-		   fsqrt(fsqrt(1<<(CONFIG_FIGHTER_DEFENSE
+		   fsqrt(fsqrt(1<<(LW_CONFIG_CURRENT_RULES.fighter_defense
 				   +cpu_influence[i]))))
 	/(256*256);
       if (defense[i]>=MAX_FIGHTER_HEALTH)
@@ -326,7 +326,7 @@ void move_fighters (void)
 	defense[i]=1;
 
       new_health[i]= (coef*
-		      fsqrt(fsqrt(1<<(CONFIG_FIGHTER_NEW_HEALTH
+		      fsqrt(fsqrt(1<<(LW_CONFIG_CURRENT_RULES.fighter_new_health
 				      +cpu_influence[i]))))
 	/(256*4);
       if (new_health[i]>=MAX_FIGHTER_HEALTH)
@@ -340,8 +340,8 @@ void move_fighters (void)
   table=(GLOBAL_CLOCK/3)%2;
   f=CURRENT_ARMY;
 
-#ifndef ALLEGRO_UNIX
-  if (STARTUP_ASM)
+#ifdef ASM
+  if (STARTUP_ASM && LW_CONFIG_CURRENT_RULES.asm_algorithm)
     boost_move_fighters (CURRENT_ARMY,
 			 CURRENT_ARMY_SIZE,
 			 CURRENT_AREA,
@@ -371,7 +371,7 @@ void move_fighters (void)
 			 temp);
   else
 #else
-    temp=0;
+  temp=0;
 #endif
   for (i=0;i<CURRENT_ARMY_SIZE;++i)
     {
