@@ -533,9 +533,12 @@ static void display(void)
 {
   /*
    * the watchdog waits for secret codes to be entered
+   * 
+   * It's also very important to call this for it will call
+   * keypressed() and so will also automatically call poll_keyboard()
+   * if needed.
    */
   watchdog_update();
-
   /*
    * calls the watchdog module to see if a secret code has been
    * entered, and does the required stuff if the answer is yes
@@ -668,6 +671,7 @@ int game (void)
 		     [CONFIG_ROUNDS_PER_SEC_LIMIT])
 		{
 		  rest(1);
+		  yield_timeslice();
 		}	      
 	      last_logic_time=get_ticker();
 
