@@ -61,6 +61,7 @@
 #include "startup.h"
 #include "init.h"
 #include "mouse.h"
+#include "exit.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -81,6 +82,45 @@ int GFX_MODE_W[5]={320,512,640,800,1024};
 int GFX_MODE_H[5]={240,384,480,600,768};
 #endif
 
+#ifdef ALLEGRO_DOS
+static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_MODEX,
+				       GFX_MODEX,
+				       GFX_VESA2L,
+				       GFX_VESA2L,
+				       GFX_VESA2L};
+static int GFX_MODE_TYPE_WINDOWED[]={GFX_MODEX,
+				     GFX_MODEX,
+				     GFX_VESA2L,
+				     GFX_VESA2L,
+				     GFX_VESA2L};
+#endif
+
+#ifdef ALLEGRO_WINDOWS
+static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_DIRECTX,
+				       GFX_DIRECTX,
+				       GFX_DIRECTX,
+				       GFX_DIRECTX,
+				       GFX_DIRECTX};
+static int GFX_MODE_TYPE_WINDOWED[]={GFX_DIRECTX_WIN,
+				     GFX_DIRECTX_WIN,
+				     GFX_DIRECTX_WIN,
+				     GFX_DIRECTX_WIN,
+				     GFX_DIRECTX_WIN};
+#endif
+
+#ifdef ALLEGRO_UNIX
+static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_AUTODETECT_FULLSCREEN,
+				       GFX_AUTODETECT_FULLSCREEN,
+				       GFX_AUTODETECT_FULLSCREEN,
+				       GFX_AUTODETECT_FULLSCREEN,
+				       GFX_AUTODETECT_FULLSCREEN};
+static int GFX_MODE_TYPE_WINDOWED[]={GFX_AUTODETECT_WINDOWED,
+				     GFX_AUTODETECT_WINDOWED,
+				     GFX_AUTODETECT_WINDOWED,
+				     GFX_AUTODETECT_WINDOWED,
+				     GFX_AUTODETECT_WINDOWED};
+#endif
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -94,57 +134,20 @@ int need_to_change_mode(int res1,int res2,int flip){
 }
 
 /*------------------------------------------------------------------*/
-int set_resolution (int res, int flip, int fullscreen)
+static int try_one_mode(int res, int flip, int fullscreen)
 {
-  int ret=1;
-  int num_try;
-  int nb_try;
-
-#ifdef ALLEGRO_DOS
-  static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_MODEX,
-					 GFX_MODEX,
-					 GFX_VESA2L,
-					 GFX_VESA2L,
-					 GFX_VESA2L};
-  static int GFX_MODE_TYPE_WINDOWED[]={GFX_MODEX,
-				       GFX_MODEX,
-				       GFX_VESA2L,
-				       GFX_VESA2L,
-				       GFX_VESA2L};
-#endif
-
-#ifdef ALLEGRO_WINDOWS
-  static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_DIRECTX,
-					 GFX_DIRECTX,
-					 GFX_DIRECTX,
-					 GFX_DIRECTX,
-					 GFX_DIRECTX};
-  static int GFX_MODE_TYPE_WINDOWED[]={GFX_DIRECTX_WIN,
-				       GFX_DIRECTX_WIN,
-				       GFX_DIRECTX_WIN,
-				       GFX_DIRECTX_WIN,
-				       GFX_DIRECTX_WIN};
-#endif
-
-#ifdef ALLEGRO_UNIX
-  static int GFX_MODE_TYPE_FULLSCREEN[]={GFX_AUTODETECT_FULLSCREEN,
-					 GFX_AUTODETECT_FULLSCREEN,
-					 GFX_AUTODETECT_FULLSCREEN,
-					 GFX_AUTODETECT_FULLSCREEN,
-					 GFX_AUTODETECT_FULLSCREEN};
-  static int GFX_MODE_TYPE_WINDOWED[]={GFX_AUTODETECT_WINDOWED,
-				       GFX_AUTODETECT_WINDOWED,
-				       GFX_AUTODETECT_WINDOWED,
-				       GFX_AUTODETECT_WINDOWED,
-				       GFX_AUTODETECT_WINDOWED};
-#endif
-
+  int ret;
   int w1,h1,w2,h2;
 
+  w1 = GFX_MODE_W[res];
+  h1 = GFX_MODE_H[res];
+  w2 = GFX_MODE_W[res];
+  h2 = flip ? GFX_MODE_H[res]*2 : GFX_MODE_H[res];
+
   log_print_str("Changing video mode to ");
-  log_print_int(GFX_MODE_W[res]);
+  log_print_int(w1);
   log_print_str("x");
-  log_print_int(GFX_MODE_H[res]);
+  log_print_int(h1);
   if (fullscreen)
     log_print_str(", fullscreen");
   else
@@ -152,34 +155,94 @@ int set_resolution (int res, int flip, int fullscreen)
   if (flip)
     log_print_str(", page flipping enabled");
 
-  nb_try=0;
-  while (nb_try<5 && ret){
-    if (nb_try==0)
-      num_try=res;
-    else
-      num_try=nb_try-1;
-    nb_try++;
+  if (fullscreen)
+    ret=set_gfx_mode(GFX_MODE_TYPE_FULLSCREEN[res],w1,h1,w2,h2);
+  else
+    ret=set_gfx_mode(GFX_MODE_TYPE_WINDOWED[res],w1,h1,w2,h2);
 
-    w1 = GFX_MODE_W[num_try];
-    h1 = GFX_MODE_H[num_try];
-    w2 = GFX_MODE_W[num_try];
-    h2 = flip ? GFX_MODE_H[num_try]*2 : GFX_MODE_H[num_try];
+  if (!ret)
+    {
+      display_success_driver((char *) gfx_driver->ascii_name);
+    }
+  else
+    {
+      display_success(0);
+    }
 
-    /*
-     * First try, we try the "prefered" driver
-     */
-    if (fullscreen)
-      ret=set_gfx_mode(GFX_MODE_TYPE_FULLSCREEN[num_try],w1,h1,w2,h2);
-    else
-      ret=set_gfx_mode(GFX_MODE_TYPE_WINDOWED[num_try],w1,h1,w2,h2);
-    if (ret)
-      {
-	/*
-	 * Second try, we try Allegro's default driver
-	 */
-	ret=set_gfx_mode(GFX_AUTODETECT,w1,h1,w2,h2);
-      }
-  }
+  return ret;
+}
+
+/*------------------------------------------------------------------*/
+static int try_safe_mode()
+{
+  int ret;
+  int w,h;
+
+  w = GFX_MODE_W[0];
+  h = GFX_MODE_H[0];
+
+  log_print_str("Trying \"safe\" video mode");
+
+  ret=set_gfx_mode(GFX_SAFE,w,h,w,h);
+
+  if (!ret)
+    {
+      display_success_driver((char *) gfx_driver->ascii_name);
+    }
+  else
+    {
+      display_success(0);
+    }
+  
+  return ret;
+}
+
+/*------------------------------------------------------------------*/
+int set_resolution (int res, int flip, int fullscreen,
+		    int *flip_enabled)
+{
+  int ret=-1;
+  int toggle;
+  int i;
+
+  if (flip_enabled)
+    {
+      *flip_enabled=0;
+    }
+
+  for (toggle=0; toggle<2; ++toggle, fullscreen=!fullscreen)
+    {
+      for (i=res;i>=0 && ret;--i)
+	{
+	  if (flip)
+	    {
+	      ret=try_one_mode(i,1,fullscreen);
+	      if (flip_enabled && !ret)
+		{
+		  *flip_enabled=1;
+		} 
+	    }
+	  if (ret)
+	    {
+	      ret=try_one_mode(i,0,fullscreen);
+	    }
+	}
+      for (i=res+1;i<5 && ret;++i)
+	{
+	  if (flip)
+	    {
+	      ret=try_one_mode(i,1,fullscreen);
+	      if (flip_enabled && !ret)
+		{
+		  *flip_enabled=1;
+		} 
+	    }
+	  if (ret)
+	    {
+	      ret=try_one_mode(i,0,fullscreen);
+	    }
+	}
+    }
 
   if (!ret)
     {
@@ -198,8 +261,10 @@ int set_resolution (int res, int flip, int fullscreen)
       
       set_window_title("Liquid War " LW_VERSION);
     }
-
-  display_success_driver(!ret,(char *) gfx_driver->ascii_name);
+  else
+    {
+      my_exit(EXIT_CODE_GRAPHICS_FAIL);
+    }
 
   return (ret);
 }
