@@ -260,11 +260,11 @@ int graphic_options (void)
 	  menu_res_changed=0;
 	  fullscreen_changed=0;
 	  display_back_image ();
-	  dp=init_dialog (d,choix);
+	  dp=my_init_dialog (d,choix);
 	  my_fade_in ();
 	}
       else
-	dp=init_dialog (d,choix);
+	dp=my_init_dialog (d,choix);
 
       show_mouse(screen);
       while ((menu_res_changed==0) && 
