@@ -62,4 +62,7 @@
 /* fonctions globales                                               */
 /*==================================================================*/
 
+int lw_httputil_get_page(char *content, char *url, int size);
+void lw_httputil_text_to_urlparam(char *urlparam, char *text, int size);
+
 #endif
