@@ -56,7 +56,7 @@
 /*==================================================================*/
 
 void display_success (int success);
-void display_success_driver (int success, char *driver);
+void display_success_driver (char *driver);
 int init_all ();
 int start_graphic (void);
 
