@@ -393,7 +393,7 @@ static void box_for_choose_map (void)
   d[6].proc=NULL; /* 6 remplace par 9 pour boites des sliders */
   /* caduque depuis que my_slider fait tout tout seul */
 
-  dp=init_dialog (d,0);
+  dp=my_init_dialog (d,0);
   my_update_dialog (dp);
   shutdown_dialog (dp);
 }
