@@ -54,8 +54,10 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <time.h>
 
 #include "log.h"
+#include "server.h"
 
 /*==================================================================*/
 /* definitions de types                                             */
@@ -65,49 +67,149 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+static FILE *LW_LOG_FILE=NULL;
+static int LW_LOG_NEW_LINE=1;
+static int LW_LOG_SERVER_MODE=0;
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-void log_init(void) {
+/*
+ * Displays date and time at the beginning of each line
+ */
+static void display_date_and_time()
+{
+  time_t time_stamp;
+  struct tm *time_struct; 
+  char time_str[50]; 
 
+  if (LW_LOG_FILE && LW_LOG_NEW_LINE && LW_LOG_SERVER_MODE)
+    {
+      time_stamp=time(NULL);
+      time_struct=localtime(&time_stamp);
+      sprintf(time_str,"%04d-%02d-%02d %02d:%02d:%02d: ",
+	      time_struct->tm_year+1900,
+	      time_struct->tm_mon+1,
+	      time_struct->tm_mday,
+	      time_struct->tm_hour,
+	      time_struct->tm_min,
+	      time_struct->tm_sec);
+
+      fprintf(LW_LOG_FILE,time_str);
+    }
+  LW_LOG_NEW_LINE=0;
 }
 
 /*------------------------------------------------------------------*/
-void log_exit(void) {
-
+static void prepare_new_line()
+{
+  if (LW_LOG_FILE)
+    {
+      fflush(LW_LOG_FILE);
+    }
+  LW_LOG_NEW_LINE=1;
 }
 
 /*------------------------------------------------------------------*/
-void log_print_str(char *str){
-  	printf("%s",str);
+void log_init(void) 
+{
+  char *filename;
+
+  filename=lw_server_get_log();
+
+  if (filename && strlen(filename)>0)
+    {
+      LW_LOG_FILE=fopen(filename,"a");
+    }
+
+  /*
+   * By default, we output stuff to stdout
+   */
+  if (LW_LOG_FILE==NULL)
+    {
+      LW_LOG_FILE=stdout;
+    }
 }
 
 /*------------------------------------------------------------------*/
-void log_print_int(int i){
-	printf("%d",i);
+void log_exit(void) 
+{
+  if (LW_LOG_FILE && LW_LOG_FILE!=stdout)
+    {
+      fclose(LW_LOG_FILE);
+    }
 }
 
 /*------------------------------------------------------------------*/
-void log_println(){
-	printf("\n");
+void log_print_str(char *str)
+{
+  if (LW_LOG_FILE)
+    {
+      display_date_and_time();
+      fprintf(LW_LOG_FILE,"%s",str);
+    }
 }
 
 /*------------------------------------------------------------------*/
-void log_println_str(char *str){
-	printf("%s\n",str);
+void log_print_int(int i)
+{
+  if (LW_LOG_FILE)
+    {
+      display_date_and_time();
+      fprintf(LW_LOG_FILE,"%d",i);
+    }
 }
 
 /*------------------------------------------------------------------*/
-void log_println_int(int i){
-	printf("%d\n",i);
+void log_println()
+{
+  if (LW_LOG_FILE)
+    {
+      display_date_and_time();
+      fprintf(LW_LOG_FILE,"\n");
+      log_flush();
+      prepare_new_line();
+    }
 }
 
 /*------------------------------------------------------------------*/
-void log_flush(){
-	fflush(stdout);
+void log_println_str(char *str)
+{
+  if (LW_LOG_FILE)
+    {
+      display_date_and_time();
+      fprintf(LW_LOG_FILE,"%s\n",str);
+      log_flush();
+      prepare_new_line();
+    }
 }
 
+/*------------------------------------------------------------------*/
+void log_println_int(int i)
+{
+  if (LW_LOG_FILE)
+    {
+      display_date_and_time();
+      fprintf(LW_LOG_FILE,"%d\n",i);
+      log_flush();
+      prepare_new_line();
+    }
+}
 
+/*------------------------------------------------------------------*/
+void log_flush()
+{
+  if (LW_LOG_FILE)
+    {
+      fflush(LW_LOG_FILE);
+    }
+}
+
+/*------------------------------------------------------------------*/
+void log_set_server_mode(int mode)
+{
+  LW_LOG_SERVER_MODE=mode;
+}
 
