@@ -115,7 +115,7 @@ void main_menu (void)
 
   display_back_image ();
   /*
-    dp=init_dialog (d,4);
+    dp=my_init_dialog (d,4);
     my_update_dialog (dp);
     shutdown_dialog (dp);
   */
