@@ -418,7 +418,7 @@ void move_all_cursors (void)
    * the right place because of performance issues
    */
 
-  for (j=0; j<=CONFIG_CURSOR_INCREASE_SPEED; ++j)
+  for (j=0; j<=LW_CONFIG_CURRENT_RULES.cursor_increase_speed; ++j)
     {
       /*
        * loop for all the teams, the cursor of which is active
@@ -432,7 +432,8 @@ void move_all_cursors (void)
 	       */
 	      if (!CURRENT_CURSOR[i].from_network)
 		{
-		  if (CURRENT_CURSOR[i].cpu_or_human)
+		  if (CURRENT_CURSOR[i].control_type == 
+		      CONFIG_CONTROL_TYPE_CPU)
 		    {
 		      /*
 		       * the cursor is controlled by the computer
