@@ -177,6 +177,8 @@ static char *read_word(char **message)
 	      strncpy(result,begin,len);
 	    }
 	  result[len]=0;
+
+	  lw_netmess_cleanup_arg(result);
 	}
     }
   eat_space(message);
@@ -281,6 +283,14 @@ static int get_code(char **message)
 	    {
 	      result=LW_NETMESS_CODE_RECVCONFIG;
 	    }
+	  else if (strcasecmp(command,LW_NETMESS_TEXT_CHATTALK)==0)
+	    {
+	      result=LW_NETMESS_CODE_CHATTALK;
+	    }
+	  else if (strcasecmp(command,LW_NETMESS_TEXT_CHATLISTEN)==0)
+	    {
+	      result=LW_NETMESS_CODE_CHATLISTEN;
+	    }
 
 	  free(command);
 	}
@@ -303,13 +313,14 @@ int get_argc(char *message)
 
   if (read_separator(&message)==0)
     {
+      if (message[0]=='\0')
+	{
+	  null_arg=1;
+	}
+
       word=read_word(&message);
       if (word!=NULL)
 	{
-	  if (strcmp(word,"")==0)
-	    {
-	      null_arg=1;
-	    }
 	  free(word);
 	  result=1;
 	  while (read_separator(&message)==1)
@@ -422,3 +433,25 @@ void lw_netmess_free(LW_NETMESS *ptr)
     }
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Cleanups strings so that they can be used as arguments in
+ * network messages
+ */
+void lw_netmess_cleanup_arg(char *string)
+{
+  char *pos;
+  unsigned char c;
+
+  pos=string;
+  while ((c=*pos)!='\0')
+    {      
+      if (c<32 || c>127 ||
+	  strchr("'\",",c))
+      {
+	(*pos)=' ';
+      }	  
+      pos++;
+    }  
+}
+
