@@ -84,7 +84,11 @@ void lw_network_attribute_colors()
 	{
 	  if (LW_NETWORK_INFO[i].network)
 	    {
-	      LW_NETWORK_INFO[i].color=0;
+	      /*
+	       * -1 is a temporary value which will be overwritten
+	       * by the _real_ value later
+	       */
+	      LW_NETWORK_INFO[i].color=-1;
 	    }
 	  else
 	    {
@@ -100,7 +104,7 @@ void lw_network_attribute_colors()
 	  duplicate=1;
 	  while (duplicate)
 	    {
-	      color=(rand()%12)+1;
+	      color=(rand()%12);
 	      duplicate=0;
 	      for (j=0;j<NB_TEAMS;++j)
 		{
