@@ -126,7 +126,7 @@ int play_sequence_ex (void)
    * we call update dialog artificially so that the "Get ready"
    * message is actually blitted on the screen
    */
-  dp=init_dialog (d,0);
+  dp=my_init_dialog (d,0);
   my_update_dialog (dp);
   shutdown_dialog (dp);
 
