@@ -298,7 +298,7 @@ int display_scores (void)
   d[MENU_QUICK_PLAY].flags=D_HIDDEN;
 
   display_back_image ();
-  dp=init_dialog (d,0);
+  dp=my_init_dialog (d,0);
   my_update_dialog (dp);
   shutdown_dialog (dp);
 
@@ -311,7 +311,7 @@ int display_scores (void)
     {
       if (!last_draw_done)
 	{
-	  dp=init_dialog (d,choix);
+	  dp=my_init_dialog (d,choix);
 	  while (my_update_dialog (dp) && !last_draw_done)
 	    {
 	      scare_mouse();
