@@ -79,6 +79,9 @@ static int handle_next(LW_SRVCHAN *chan, LW_NETMESS *mess,
 		       int *next);
 static int handle_teamstartinfo(LW_SRVCHAN *chan, LW_NETMESS *mess,
 				LW_TEAMSTARTINFO *team_start_info);
+static int handle_chattalk(LW_SRVCHAN *chan, LW_NETMESS *mess,
+				LW_CHAT_HISTORY *chat);
+static int handle_chatlisten(LW_SRVCHAN *chan, LW_NETMESS *mess);
 static int handle_who(LW_SRVCHAN *chan, LW_NETMESS *mess);
 static int handle_sendmap(LW_SRVCHAN *chan, LW_NETMESS *mess, 
 			  void **map);
@@ -110,6 +113,7 @@ static void reset(LW_SRVCHAN *chan)
     {
       lw_srvteam_reset(&(chan->team[i]));
     }
+  lw_chat_reset(&(chan->chat));
 }
 
 /*------------------------------------------------------------------*/
@@ -553,6 +557,93 @@ static int handle_teamstartinfo(LW_SRVCHAN *chan, LW_NETMESS *mess,
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * handles the "CHATTALK" message
+ */
+static int handle_chattalk(LW_SRVCHAN *chan, LW_NETMESS *mess,
+			   LW_CHAT_HISTORY *chat)
+{
+  int result=0;
+
+  if (mess->argc==1)
+    {
+      /*
+       * OK, there's an argument, we interpret it as a message.
+       * Note that we push the message in a common chat history
+       * struct, to share it with others.
+       */
+      log_print_str("Client \"");
+      log_print_str(chan->ip);
+      log_print_str(":");
+      log_print_int(chan->port);
+      log_print_str("\" says \"");
+      log_print_str(mess->argv[0]);
+      log_println_str("\"");
+
+      lw_chat_push(chat,chan->team[0].name,mess->argv[0]);
+
+      result=1;
+    }
+
+  /*
+   * Now we send feedback on the network
+   */
+  if (result)
+    {
+      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK);
+    }
+  else
+    {
+      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * handles the "CHATLISTEN" message
+ */
+static int handle_chatlisten(LW_SRVCHAN *chan, LW_NETMESS *mess)
+{
+  int result=0;
+  char answer[LW_SOCK_MESSAGE_SIZE];
+  LW_CHAT_MESSAGE message;
+
+  if (mess->argc==0)
+    {
+      if (lw_chat_pop(&(chan->chat),&message))
+	{
+	  /*
+	   * OK, there's a message in the queue, we send it
+	   */
+	  sprintf(answer,"%s '%s','%s'",
+		  LW_NETMESS_TEXT_OK,
+		  message.author,
+		  message.content);
+	}
+      else
+	{
+	  sprintf(answer,LW_NETMESS_TEXT_OK);
+	}
+
+      lw_sock_send_str(chan->sock,answer);
+
+      result=1;
+    }
+
+  /*
+   * Send error message if needed
+   */
+  if (!result)
+    {
+      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+    }
+
+  return result;
+}
+
 /*------------------------------------------------------------------*/
 /*
  * handles the "SENDMAP" message
@@ -824,7 +915,8 @@ int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
  */
 int lw_srvchan_keepalive(LW_SRVCHAN *chan,
 			 int waited_teams,
-			 LW_TEAMSTARTINFO *team_start_info)
+			 LW_TEAMSTARTINFO *team_start_info,
+			 LW_CHAT_HISTORY *chat)
 {
   int result=0;
   int ret;
@@ -878,6 +970,13 @@ int lw_srvchan_keepalive(LW_SRVCHAN *chan,
 		      ret_mess=handle_teamstartinfo(chan,mess,
 						    team_start_info);
 		      break;
+		    case LW_NETMESS_CODE_CHATTALK:
+		      ret_mess=handle_chattalk(chan,mess,
+					       chat);
+		      break;
+		    case LW_NETMESS_CODE_CHATLISTEN:
+		      ret_mess=handle_chatlisten(chan,mess);
+		      break;
 		    case LW_NETMESS_CODE_READY:
 		      ret_mess=handle_ready(chan,mess);
 		      break;
