@@ -62,6 +62,7 @@
 #include "netconf.h"
 #include "startinf.h"
 #include "netmess.h"
+#include "chat.h"
 
 /*==================================================================*/
 /* structs                                                          */
@@ -80,6 +81,7 @@ typedef struct
   void *map;
   LW_NETCONF config;
   LW_SRVTEAM team[NB_TEAMS];
+  LW_CHAT_HISTORY chat;
 } LW_SRVCHAN;
 
 /*==================================================================*/
@@ -89,7 +91,8 @@ typedef struct
 int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
 			  int sock, void **map,LW_NETCONF *config);
 int lw_srvchan_keepalive(LW_SRVCHAN *chan, int waited_teams,
-			 LW_TEAMSTARTINFO *team_start_info);
+			 LW_TEAMSTARTINFO *team_start_info,
+			 LW_CHAT_HISTORY *chat);
 int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config);
 int lw_srvchan_final_ok(LW_SRVCHAN *chan);
 int lw_srvchan_find_team_by_server_id(LW_SRVCHAN *chan,int server_id);
