@@ -353,9 +353,7 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
       /*
        * Now we just wait until there are enough teams connected
        */
-      while (cont->nb_teams<nb_teams && 
-	     cont->nb_chans<NB_TEAMS &&
-	     !started)
+      while (!started)
 	{
 	  free_teams=nb_teams-cont->nb_teams;
 
@@ -395,21 +393,35 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
 	    {
 	      start=start && cont->chan[i].start;
 	    }
-	  if (start && cont->nb_teams>=2)
+	  if (cont->nb_teams>=2 &&
+	      (start || cont->nb_teams>=nb_teams))
 	    {
-	      /*
-	       * OK, all the players have pressed the "start" button and there
-	       * are at least 2 playing teams -> we start the game!
-	       */ 
-	      nb_teams=cont->nb_teams;
+	      if (cont->nb_teams<nb_teams)
+		{
+		  /*
+		   * OK, all the players have pressed the "start" button and there
+		   * are at least 2 playing teams -> we start the game!
+		   */ 
+		  nb_teams=cont->nb_teams;
+		  log_print_str("Starting game with only ");
+		  log_print_int(cont->nb_teams);
+		  log_println_str(" teams");
+		}
 	      free_teams=0;
-	      log_print_str("Starting game with only ");
-	      log_print_int(cont->nb_teams);
-	      log_println_str(" teams");
+	    }
 
+	  /*
+	   * The official start signal is: free_teams is set to 0.
+	   * We use an extra flag "started" in case free_teams would
+	   * be recalculated
+	   */
+	  if (free_teams<=0)
+	    {
+	      free_teams=0;
 	      started=1;
 	    }
 
+
 	  /*
 	   * We replicate chat messages
 	   */
